@@ -18,14 +18,14 @@ along with multiple :class:`~tensorbay.sensor.sensor.Sensors`.
 
 from typing import TYPE_CHECKING, Any, Callable, MutableSequence, Optional, Type, TypeVar
 
-from ..sensor import Sensors
-from ..utility import NameMixin, ReprType, UserMutableSequence
-from .frame import Frame
+from tensorbay.dataset.frame import Frame
+from tensorbay.sensor import Sensors
+from tensorbay.utility import NameMixin, ReprType, UserMutableSequence
 
 if TYPE_CHECKING:
-    from ..client.dataset import DatasetClient, FusionDatasetClient
-    from ..client.segment import FusionSegmentClient, SegmentClient
-    from .data import DataBase
+    from tensorbay.client.dataset import DatasetClient, FusionDatasetClient
+    from tensorbay.client.segment import FusionSegmentClient, SegmentClient
+    from tensorbay.dataset.data import DataBase
 
 _S = TypeVar("_S", bound="Segment")
 _FS = TypeVar("_FS", bound="FusionSegment")
@@ -60,7 +60,7 @@ class Segment(NameMixin, UserMutableSequence["DataBase._Type"]):
 
     _repr_type = ReprType.SEQUENCE
 
-    def __init__(self, name: str = "", client: Optional["DatasetClient"] = None) -> None:
+    def __init__(self, name: str = "default", client: Optional["DatasetClient"] = None) -> None:
         super().__init__(name)
 
         if client:
@@ -81,7 +81,6 @@ class Segment(NameMixin, UserMutableSequence["DataBase._Type"]):
             The Segment of the input :class:`~tensorbay.client.segment.SegmentClient`.
 
         """
-        # pylint: disable=protected-access
         segment = cls(client.name)
         segment._client = client
         segment._data = client.list_data()  # type: ignore[assignment]
@@ -154,7 +153,9 @@ class FusionSegment(NameMixin, UserMutableSequence[Frame]):
     _repr_attrs = ("sensors",)
     _repr_maxlevel = 2
 
-    def __init__(self, name: str = "", client: Optional["FusionDatasetClient"] = None) -> None:
+    def __init__(
+        self, name: str = "default", client: Optional["FusionDatasetClient"] = None
+    ) -> None:
         super().__init__(name)
 
         self._data: MutableSequence[Frame]
@@ -177,9 +178,8 @@ class FusionSegment(NameMixin, UserMutableSequence[Frame]):
             The FusionSegment of the input :class:`~tensorbay.client.segment.FusionSegmentClient`.
 
         """
-        # pylint: disable=protected-access
         segment: _FS = object.__new__(cls)
-        super(cls, segment).__init__(client.name)
+        super(cls, segment).__init__(name=client.name)  # pylint: disable=no-value-for-parameter
         segment._client = client
         segment._data = client.list_frames()
         segment._repr_non_empty = True
