@@ -24,23 +24,13 @@ with warnings.catch_warnings():
     warnings.simplefilter("ignore")
     from quaternion import quaternion
 
-from ..geometry import Box2D, Box3D, Transform3D
-from ..utility import (
-    MatrixType,
-    ReprType,
-    SubcatalogTypeRegister,
-    TypeRegister,
-    attr_base,
-    common_loads,
-)
-from .basic import LabelType, SubcatalogBase, _LabelBase
-from .supports import AttributesMixin, CategoriesMixin, IsTrackingMixin
+from tensorbay.geometry import Box2D, Box3D, Transform3D
+from tensorbay.label.basic import SubcatalogBase, _LabelBase
+from tensorbay.label.supports import AttributesMixin, CategoriesMixin, IsTrackingMixin
+from tensorbay.utility import MatrixType, ReprType, attr_base, common_loads
 
 
-@SubcatalogTypeRegister(LabelType.BOX2D)
-class Box2DSubcatalog(  # pylint: disable=too-many-ancestors
-    SubcatalogBase, IsTrackingMixin, CategoriesMixin, AttributesMixin
-):
+class Box2DSubcatalog(SubcatalogBase, IsTrackingMixin, CategoriesMixin, AttributesMixin):
     """This class defines the subcatalog for 2D box type of labels.
 
     Arguments:
@@ -107,8 +97,7 @@ class Box2DSubcatalog(  # pylint: disable=too-many-ancestors
         IsTrackingMixin.__init__(self, is_tracking)
 
 
-@TypeRegister(LabelType.BOX2D)
-class LabeledBox2D(_LabelBase, Box2D):  # pylint: disable=too-many-ancestors
+class LabeledBox2D(_LabelBase, Box2D):
     """This class defines the concept of 2D bounding box label.
 
     :class:`LabeledBox2D` is the 2D bounding box type of label,
@@ -272,10 +261,7 @@ class LabeledBox2D(_LabelBase, Box2D):  # pylint: disable=too-many-ancestors
         return self._dumps()
 
 
-@SubcatalogTypeRegister(LabelType.BOX3D)
-class Box3DSubcatalog(  # pylint: disable=too-many-ancestors
-    SubcatalogBase, IsTrackingMixin, CategoriesMixin, AttributesMixin
-):
+class Box3DSubcatalog(SubcatalogBase, IsTrackingMixin, CategoriesMixin, AttributesMixin):
     """This class defines the subcatalog for 3D box type of labels.
 
     Arguments:
@@ -342,7 +328,6 @@ class Box3DSubcatalog(  # pylint: disable=too-many-ancestors
         IsTrackingMixin.__init__(self, is_tracking)
 
 
-@TypeRegister(LabelType.BOX3D)
 class LabeledBox3D(_LabelBase, Box3D):
     """This class defines the concept of 3D bounding box label.
 
