@@ -17,21 +17,12 @@ which is often used for tasks such as automatic speech recognition.
 
 from typing import Any, Dict, Iterable, List, Optional, Type, TypeVar, Union
 
-from ..utility import (
-    AttrsMixin,
-    ReprMixin,
-    SubcatalogTypeRegister,
-    TypeRegister,
-    attr,
-    camel,
-    common_loads,
-)
-from .basic import LabelType, SubcatalogBase, _LabelBase
-from .supports import AttributesMixin
+from tensorbay.label.basic import SubcatalogBase, _LabelBase
+from tensorbay.label.supports import AttributesMixin
+from tensorbay.utility import AttrsMixin, ReprMixin, attr, camel, common_loads
 
 
-@SubcatalogTypeRegister(LabelType.SENTENCE)
-class SentenceSubcatalog(SubcatalogBase, AttributesMixin):  # pylint: disable=too-many-ancestors
+class SentenceSubcatalog(SubcatalogBase, AttributesMixin):
     """This class defines the subcatalog for audio transcripted sentence type of labels.
 
     Arguments:
@@ -218,7 +209,6 @@ class Word(ReprMixin, AttrsMixin):
         return self._dumps()
 
 
-@TypeRegister(LabelType.SENTENCE)  # pylint: disable=too-few-public-methods
 class LabeledSentence(_LabelBase):
     """This class defines the concept of phonetic transcription lable.
 
@@ -278,9 +268,7 @@ class LabeledSentence(_LabelBase):
 
     _T = TypeVar("_T", bound="LabeledSentence")
 
-    _label_attrs = ("attributes",)
-
-    _repr_attrs = ("sentence", "spell", "phone") + _label_attrs
+    _repr_attrs = ("sentence", "spell", "phone", "attributes")
     _repr_maxlevel = 3
 
     sentence: List[Word] = attr(is_dynamic=True)
