@@ -8,7 +8,7 @@
 from glob import glob as buildin_glob
 from typing import List
 
-from ...exception import NoFileError
+from tensorbay.exception import NoFileError
 
 
 def glob(pathname: str, *, recursive: bool = False) -> List[str]:
@@ -32,7 +32,7 @@ def glob(pathname: str, *, recursive: bool = False) -> List[str]:
     """
     paths = buildin_glob(pathname, recursive=recursive)
     if not paths:
-        raise NoFileError(pathname)
+        raise NoFileError(pattern=pathname)
     paths.sort()
 
     return paths
